@@ -14,5 +14,10 @@ urlpatterns = patterns('feedzilla.views',
 )
 
 urlpatterns += patterns('django.contrib.syndication.views',
+    # WTF???
     url(r'^ru/projects/feed$', PostFeed(), name='feedzilla_feed'),
+    # depprecated
+    url(r'^feeds/posts$', PostFeed(), name='feedzilla_feed'),
+    # new
+    url(r'^feed/post$', PostFeed(), name='feedzilla_feed'),
 )
